import 'package:example/main.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';

class AdsController extends GetxController {
  InterstitialAd? interstitialAd;
  int _numInterstitialLoadAttempts = 0;
  int maxFailedLoadAttempts = 3;

  AdWidget? adWidgetBanner;

  final BannerAd myBanner = BannerAd(
    adUnitId: Constants.ADMOB_BANNER_ID,
    size: AdSize.mediumRectangle,
    request: AdRequest(),
    listener: BannerAdListener(),
  );

  @override
  onInit() {
    super.onInit();
    loadInterstialAdMob();
    myBanner.load();
    adWidgetBanner = AdWidget(ad: myBanner);
  }

  @override
  onReady() {
    super.onReady();
  }

  Container get adBannerContainer => Container(
        alignment: Alignment.center,
        child: adWidgetBanner,
        width: myBanner.size.width.toDouble(),
        height: myBanner.size.height.toDouble(),
      );

  void _createInterstitialAd() {
    InterstitialAd.load(
        adUnitId: InterstitialAd.testAdUnitId,
        request: AdRequest(),
        adLoadCallback: InterstitialAdLoadCallback(
          onAdLoaded: (InterstitialAd ad) {
            print('$ad loaded');
            interstitialAd = ad;
            _numInterstitialLoadAttempts = 0;
          },
          onAdFailedToLoad: (LoadAdError error) {
            print('InterstitialAd failed to load: $error.');
            _numInterstitialLoadAttempts += 1;
            interstitialAd = null;
            if (_numInterstitialLoadAttempts <= maxFailedLoadAttempts) {
              _createInterstitialAd();
            }
          },
        ));
  }

  loadInterstialAdMob() {
    InterstitialAd.load(
        adUnitId: Constants.ADMOB_INTERSTITIAL_ID,
        request: AdRequest(),
        adLoadCallback: InterstitialAdLoadCallback(
          onAdLoaded: (InterstitialAd ad) {
            // Keep a reference to the ad so you can show it later.
            this.interstitialAd = ad;
          },
          onAdFailedToLoad: (LoadAdError error) {
            print('InterstitialAd failed to load: $error');
          },
        ));
  }

  showAdInterstitial(dynamic router) {
    //insertInterstitialCode
    if (interstitialAd == null) {
      print('Warning: attempt to show interstitial before loaded.');
      router();
      // if (_numInterstitialLoadAttempts <= maxFailedLoadAttempts) {
      //   _createInterstitialAd();
      // }
      return;
    }

    interstitialAd!.fullScreenContentCallback = FullScreenContentCallback(
      onAdShowedFullScreenContent: (InterstitialAd ad) =>
          print('ad onAdShowedFullScreenContent.'),
      onAdDismissedFullScreenContent: (InterstitialAd ad) {
        print('$ad onAdDismissedFullScreenContent.');
        ad.dispose();
        _createInterstitialAd();
        router();
      },
      onAdFailedToShowFullScreenContent: (InterstitialAd ad, AdError error) {
        print('$ad onAdFailedToShowFullScreenContent: $error');
        ad.dispose();
        router();
        _createInterstitialAd();
      },
    );
    interstitialAd!.show();
    interstitialAd = null;
  }
}
