import 'dart:typed_data';

import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:get/get.dart';
import 'package:image_gallery_saver/image_gallery_saver.dart';
import 'package:pacote_sc/controllers/create_controller.dart';
import 'package:permission_handler/permission_handler.dart';

class ScanCreateScreen extends StatelessWidget {
  final Color colorPrimary;
  ScanCreateScreen({Key? key, required this.colorPrimary}) : super(key: key);

  final controller = Get.put(CreateController());
  Widget _qrCodeWidget(Uint8List bytes, BuildContext context) {
    return Padding(
      padding: EdgeInsets.symmetric(vertical: 8, horizontal: 0),
      child: Card(
        child: Column(
          children: <Widget>[
            Container(
              child: Row(
                crossAxisAlignment: CrossAxisAlignment.end,
                children: <Widget>[
                  Icon(Icons.verified_user, size: 18, color: Colors.green),
                  Text('  Generate QRcode', style: TextStyle(fontSize: 15)),
                  Spacer(),
                ],
              ),
              padding: EdgeInsets.symmetric(horizontal: 10, vertical: 9),
              decoration: BoxDecoration(
                color: Colors.black12,
                borderRadius: BorderRadius.only(
                    topLeft: Radius.circular(4), topRight: Radius.circular(4)),
              ),
            ),
            Padding(
              padding:
                  EdgeInsets.only(left: 40, right: 40, top: 30, bottom: 10),
              child: Column(
                children: <Widget>[
                  SizedBox(
                    height: 190,
                    child: bytes.isEmpty
                        ? Center(
                            child: Text('Empty code ... ',
                                style: TextStyle(color: Colors.black38)),
                          )
                        : Image.memory(bytes),
                  ),
                  Padding(
                    padding: EdgeInsets.only(top: 7, left: 25, right: 25),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                      children: <Widget>[
                        Expanded(
                          flex: 5,
                          child: MaterialButton(
                            onPressed: () =>
                                controller.imageFile.value = Uint8List(0),
                            child: Text(
                              'Remove',
                              style:
                                  TextStyle(fontSize: 15, color: Colors.blue),
                            ),
                          ),
                        ),
                        Text('|',
                            style:
                                TextStyle(fontSize: 15, color: Colors.black26)),
                        Expanded(
                          flex: 5,
                          child: Obx(() {
                            debugPrint(
                                'button: ${controller.qrCodeOfInput.value.length}');
                            return MaterialButton(
                              onPressed: controller.qrCodeOfInput.value.length >
                                      0
                                  ? () async {
                                      var status =
                                          await Permission.storage.status;
                                      switch (status) {
                                        case PermissionStatus.granted:
                                          final success =
                                              await ImageGallerySaver.saveImage(
                                                  controller.imageFile.value);
                                          debugPrint(
                                              'debugPrint ${success['isSuccess']}');
                                          if (success['isSuccess']) {
                                            Get.snackbar(
                                              'Successful',
                                              'Successful Preservation!',
                                              snackPosition:
                                                  SnackPosition.BOTTOM,
                                              backgroundColor: Colors.green,
                                              colorText: Colors.white,
                                            );
                                          } else {
                                            Get.snackbar(
                                              'Error',
                                              success.errorMessage,
                                              snackPosition:
                                                  SnackPosition.BOTTOM,
                                              backgroundColor: Colors.red,
                                              colorText: Colors.white,
                                            );
                                          }
                                          break;
                                        default:
                                          bool isShow = await Permission.storage
                                              .shouldShowRequestRationale;
                                          if (isShow)
                                            await Permission.storage.request();
                                          else
                                            Get.defaultDialog(
                                              title: 'Storage Permission',
                                              buttonColor: colorPrimary,
                                              confirmTextColor: Colors.white,
                                              cancelTextColor: Colors.black,
                                              middleText:
                                                  'This app needs storage access to save QR code.',
                                              textCancel: 'Deny',
                                              textConfirm: 'Open Settings',
                                              onConfirm: () =>
                                                  openAppSettings(),
                                            );
                                      }
                                    }
                                  : null,
                              child: Text(
                                'Save',
                                style:
                                    TextStyle(fontSize: 15, color: Colors.blue),
                                textAlign: TextAlign.right,
                              ),
                            );
                          }),
                        ),
                      ],
                    ),
                  ),
                ],
              ),
            ),
            Divider(height: 2, color: Colors.black26),
          ],
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Create your QR Code"),
        elevation: 0,
      ),
      body: Container(
        color: colorPrimary,
        child: SingleChildScrollView(
          child: Obx(
            () => Padding(
              padding: const EdgeInsets.all(8.0),
              child: Column(
                children: [
                  _qrCodeWidget(controller.imageFile.value, context),
                  Container(
                    child: Column(
                      children: <Widget>[
                        Card(
                          child: Padding(
                            padding: const EdgeInsets.all(8.0),
                            child: TextField(
                              controller: controller.textEditingController,
                              keyboardType: TextInputType.url,
                              textInputAction: TextInputAction.go,
                              maxLines: 1,
                              onSubmitted: (value) =>
                                  controller.generateBarCode(value),
                              decoration: InputDecoration(
                                border: OutlineInputBorder(),
                                prefixIcon: Icon(Icons.text_fields),
                                helperText:
                                    'Please input your code to generage qrcode image.',
                                hintText: 'Please Input Your Code',
                                hintStyle: TextStyle(fontSize: 15),
                                contentPadding: EdgeInsets.symmetric(
                                  horizontal: 7,
                                  vertical: 15,
                                ),
                              ),
                            ),
                          ),
                        ),
                        SizedBox(height: 20),
                      ],
                    ),
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}
